import os
import shutil
import nbconvert

templates = {"jupyter.tplx","style_jupyter.tplx"}
nbconvert_path = os.path.dirname(nbconvert.__file__)
to_path = os.path.abspath(os.path.join(nbconvert_path,"templates","latex"))
if not os.path.isdir(to_path):
    raise OSError("Directory: %s not found." % to_path)

path = os.path.dirname(os.path.realpath(__file__))
from_path = os.path.abspath(os.path.join(path,"templates"))
found_templates = os.listdir(from_path)
if templates != set(found_templates):
    raise ValueError("Templates not found")

for template in templates:
    src = os.path.join(from_path,template)
    shutil.copy(src,to_path)

print("Success")


from setuptools import setup

setup(name='nb_pdf_template',
      version='1.0.0',
      description='LaTeX templates for jupyter notebook conversion to pdf',
      url='https://github.com/t-makaro/nb_pdf_template',
      author='Tyler Makaro',
      author_email='',
      license='MIT',
      packages=['nb_pdf_template'],
      include_package_data = True,
      classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
      ],
      zip_safe=False)